package com.hw.ems.base.service;

import com.hw.common.core.domain.Ztree;
import com.hw.ems.base.domain.BaseBuildInfo;
import com.hw.ems.base.domain.BaseMonitorInfo;
import com.hw.ems.base.domain.vo.TreeSelect;

import java.util.List;


/**
 * 建筑信息管理Service接口
 *
 * @author YinQ
 * @date 2023-05-05
 */
public interface IBaseBuildInfoService
{
    /**
     * 查询建筑信息管理
     *
     * @param objid 建筑信息管理主键
     * @return 建筑信息管理
     */
    public BaseBuildInfo selectBaseBuildInfoByObjid(Long objid);

    /**
     * 查询建筑信息管理列表
     *
     * @param baseBuildInfo 建筑信息管理
     * @return 建筑信息管理集合
     */
    public List<BaseBuildInfo> selectBaseBuildInfoList(BaseBuildInfo baseBuildInfo);

    /**
     * 新增建筑信息管理
     *
     * @param baseBuildInfo 建筑信息管理
     * @return 结果
     */
    public int insertBaseBuildInfo(BaseBuildInfo baseBuildInfo);

    /**
     * 修改建筑信息管理
     *
     * @param baseBuildInfo 建筑信息管理
     * @return 结果
     */
    public int updateBaseBuildInfo(BaseBuildInfo baseBuildInfo);

    /**
     * 批量删除建筑信息管理
     *
     * @param objids 需要删除的建筑信息管理主键集合
     * @return 结果
     */
    public int deleteBaseBuildInfoByObjids(Long[] objids);

    /**
     * 删除建筑信息管理信息
     *
     * @param objid 建筑信息管理主键
     * @return 结果
     */
    public int deleteBaseBuildInfoByObjid(Long objid);

    public List<BaseBuildInfo> selectBuildList(BaseMonitorInfo baseMonitorInfo);
    public List<TreeSelect> buildTreeSelect(List<BaseBuildInfo> builds);
    public List<BaseBuildInfo> buildTree(List<BaseBuildInfo> menus);

    List<Ztree> selectBaseBuildInfoTree();
}
